@@ -9,12 +9,7 @@ try:
 except ImportError:
     socks = None
 
-import six
-if six.PY2:
-    from urlparse import urlparse
-    input = raw_input
-elif six.PY3:
-    from urllib.parse import urlparse
+from urllib.parse import urlparse
 
 from .select import Select
 from .help import Inspector, GraphData, PaintGraph, _DRAW_GRAPHS
@@ -433,8 +428,9 @@ class Interface(object):
             raise NotImplementedError(
                 'no save_config() for anonymous interfaces')
 
-        if not os.path.exists(os.path.dirname(location)):
-            os.makedirs(os.path.dirname(location))
+        expanded_path = os.path.abspath(os.path.expanduser(location))
+        if not os.path.exists(os.path.dirname(expanded_path)):
+            os.makedirs(os.path.dirname(expanded_path))
 
         config = {'server': self._server,
                   'user': self._user,
@@ -446,7 +442,7 @@ class Interface(object):
         if self._proxy_url:
             config['proxy'] = self._proxy_url.geturl()
 
-        with open(location, 'w') as fp:
+        with open(expanded_path, 'w') as fp:
             json.dump(config, fp)
 
     def load_config(self, location):
