@@ -1,7 +1,6 @@
 import unittest
-import os.path as op
 from pyxnat import Interface
-from . import skip_if_no_network
+from pyxnat.tests import skip_if_no_network
 import logging as log
 log.basicConfig(level=log.INFO)
 
@@ -10,8 +9,7 @@ class ArrayTests(unittest.TestCase):
     ''' Resource-related XNAT connectivity test cases '''
 
     def setUp(self):
-        fp = op.join(op.dirname(op.abspath(__file__)), 'central.cfg')
-        self._intf = Interface(config=fp)
+        self._intf = Interface('https://www.nitrc.org/ir', anonymous=True)
 
     @skip_if_no_network
     def test_array_experiments(self):
@@ -20,8 +18,8 @@ class ArrayTests(unittest.TestCase):
         of experiments (i.e. MRSessions and PETSessions) and assert it gathers
         them all.
         '''
-        e = self._intf.array.experiments(subject_id='CENTRAL_S06242').data
-        self.assertGreaterEqual(len(e), 3)
+        e = self._intf.array.experiments(subject_id='XNAT_S04207').data
+        self.assertEqual(len(e), 2)
 
     @skip_if_no_network
     def test_array_mrsessions(self):
@@ -30,8 +28,8 @@ class ArrayTests(unittest.TestCase):
         list of MRI sessions and assert its length matches the list of
         experiments of type 'xnat:mrSessionData'
         '''
-        mris = self._intf.array.mrsessions(subject_id='CENTRAL_S06242').data
-        e = self._intf.array.experiments(subject_id='CENTRAL_S06242',
+        mris = self._intf.array.mrsessions(subject_id='XNAT_S04207').data
+        e = self._intf.array.experiments(subject_id='XNAT_S04207',
                                          experiment_type='xnat:mrSessionData')
         exps = e.data
         self.assertListEqual(mris, exps)
@@ -42,8 +40,8 @@ class ArrayTests(unittest.TestCase):
         Get a list of scans from a given experiment which has multiple types
         of scans (i.e. PETScans and CTScans) and assert it gathers them all.
         '''
-        s = self._intf.array.scans(experiment_id='CENTRAL_E72012').data
-        self.assertEqual(len(s), 16)
+        s = self._intf.array.scans(experiment_id='XNAT_E16718').data
+        self.assertEqual(len(s), 1)
 
     @skip_if_no_network
     def test_array_mrscans(self):
@@ -53,8 +51,8 @@ class ArrayTests(unittest.TestCase):
         and assert its length matches the list of scans filtered by type
         'xnat:mrScanData'
         '''
-        mris = self._intf.array.mrscans(experiment_id='CENTRAL_E72012').data
-        exps = self._intf.array.scans(experiment_id='CENTRAL_E72012',
+        mris = self._intf.array.mrscans(experiment_id='NITRC_IR_E10539').data
+        exps = self._intf.array.scans(experiment_id='NITRC_IR_E10539',
                                       scan_type='xnat:mrScanData').data
         self.assertListEqual([i['xnat:mrscandata/id'] for i in mris],
                              [i['xnat:mrscandata/id'] for i in exps])
@@ -62,7 +60,7 @@ class ArrayTests(unittest.TestCase):
     @skip_if_no_network
     def test_search_experiments(self):
         et = 'xnat:subjectData'
-        e = self._intf.array.search_experiments(project_id='nosetests5',
+        e = self._intf.array.search_experiments(project_id='ixi',
                                                 experiment_type=et)
         res = e.data
-        self.assertGreaterEqual(len(res), 1)
+        self.assertEqual(len(res), 584)
