@@ -1,11 +1,8 @@
 from pyxnat.core.help import GraphData, PaintGraph, SchemasInspector
 from pyxnat import Interface
-from . import skip_if_no_network
-import os.path as op
-
-fp = op.join(op.dirname(op.abspath(__file__)), 'central.cfg')
-central = Interface(config=fp)
+from pyxnat.tests import skip_if_no_network
 
+central = Interface('https://www.nitrc.org/ir', anonymous=True)
 
 @skip_if_no_network
 def test_graphdata():
