@@ -1,10 +1,8 @@
-import os.path as op
 from pyxnat import Interface
-from . import skip_if_no_network
+from pyxnat.tests import skip_if_no_network
 
 
-fp = op.join(op.dirname(op.abspath(__file__)), 'central.cfg')
-central = Interface(config=fp)
+central = Interface('https://www.nitrc.org/ir', anonymous=True)
 
 notified = []
 
@@ -29,6 +27,6 @@ def test_unregister_callback():
 
 @skip_if_no_network
 def test_add_schema():
-    assert(len(central.manage.schemas()) == 0)
+    assert len(central.manage.schemas()) == 0
     central.manage.schemas.add(url='/xapi/schemas/xnat')
-    assert(list(central.manage.schemas()) == ['xnat'])
+    assert list(central.manage.schemas()) == ['xnat']
