@@ -1,17 +1,17 @@
 import tempfile
 from uuid import uuid1
-from six import string_types
 import os.path as op
 import os
 from pyxnat import Interface
-from . import skip_if_no_network
-from nose import SkipTest
+from pyxnat.tests import skip_if_no_network
+import pytest
 from pyxnat.core import interfaces
 
 _modulepath = op.dirname(op.abspath(__file__))
 
-central = Interface(config=op.join(op.dirname(op.abspath(__file__)),
-                                   'central.cfg'))
+fp = op.abspath('.devxnat.cfg')
+central = Interface(config=fp)
+
 interfaces.STUBBORN = True
 
 _id_set1 = {
@@ -30,7 +30,7 @@ _id_set2 = {
     'rid': uuid1().hex,
 }
 
-subj_1 = central.select.project('nosetests5').subject(_id_set1['sid'])
+subj_1 = central.select.project('pyxnat_tests').subject(_id_set1['sid'])
 expe_1 = subj_1.experiment(_id_set1['eid'])
 asse_1 = expe_1.assessor(_id_set1['aid'])
 scan_1 = expe_1.scan(_id_set1['cid'])
@@ -55,7 +55,7 @@ def test_02_experiment_create():
 @skip_if_no_network
 def test_03_assessor_create():
     assert not asse_1.exists()
-    asse_1.create()
+    asse_1.create(assessors='xnat:qcAssessmentData')
     assert asse_1.exists()
 
 
@@ -73,28 +73,30 @@ def test_05_reconstruction_create():
     assert reco_1.exists()
 
 
-# def test_provenance():
-#     reco_1.provenance.set({'program':'nosetests'})
-#     assert reco_1.provenance.get()[0]['program'] == 'nosetests'
+@skip_if_no_network
+def test_provenance():
+    reco_1.provenance.set({'program': 'nosetests'})
+    assert reco_1.provenance.get()[0]['program'] == 'nosetests'
+
 
 @skip_if_no_network
 def test_06_multi_create():
-    asse_2 = central.select('/projects/nosetests5/subjects/%(sid)s'
+    asse_2 = central.select('/projects/pyxnat_tests/subjects/%(sid)s'
                             '/experiments/%(eid)s'
                             '/assessors/%(aid)s' % _id_set2)
 
-    expe_2 = central.select('/projects/nosetests5/subjects/%(sid)s'
+    expe_2 = central.select('/projects/pyxnat_tests/subjects/%(sid)s'
                             '/experiments/%(eid)s' % _id_set2)
 
     assert not asse_2.exists()
     asse_2.create(experiments='xnat:petSessionData',
-                  assessors='xnat:petAssessorData')
+                  assessors='xnat:qcAssessmentData')
     assert asse_2.exists()
 
-    assert asse_2.datatype() == 'xnat:petAssessorData'
+    assert asse_2.datatype() == 'xnat:qcAssessmentData'
     assert expe_2.datatype() == 'xnat:petSessionData'
 
-    scan_2 = central.select('/projects/nosetests5/subjects/%(sid)s'
+    scan_2 = central.select('/projects/pyxnat_tests/subjects/%(sid)s'
                             '/experiments/%(eid)s/scans/%(cid)s' % _id_set2
                             ).create()
 
@@ -119,7 +121,7 @@ def test_08_get_file():
     assert op.exists(fpath)
     print(['toto3', open(fpath, 'rb').read()])
     try:
-        assert open(fpath, 'rb').read() == bytes('Hello XNAT!%s' % os.linesep,
+        assert open(fpath, 'rb').read() == bytes('Hello XNAT!\n',
                                                  encoding='utf8')
     except TypeError:
         pass
@@ -148,7 +150,7 @@ def test_10_get_dir_file():
     fpath = fh.get()
     assert op.exists(fpath)
     try:
-        assert open(fpath, 'rb').read() == bytes('Hello again!%s' % os.linesep,
+        assert open(fpath, 'rb').read() == bytes('Hello again!\n',
                                                  encoding='utf8')
     except TypeError:
         pass
@@ -168,7 +170,7 @@ def test_11_get_copy_file():
     assert op.exists(fpath)
     fd = open(fpath, 'rb')
     try:
-        assert fd.read() == bytes('Hello XNAT!%s' % os.linesep,
+        assert fd.read() == bytes('Hello XNAT!\n',
                                   encoding='utf8')
     except TypeError:
         pass
@@ -179,7 +181,7 @@ def test_11_get_copy_file():
 @skip_if_no_network
 def test_12_file_last_modified():
     f = subj_1.resource('test').file('hello.txt')
-    assert isinstance(f.last_modified(), string_types)
+    assert isinstance(f.last_modified(), str)
     assert len(f.last_modified()) > 0
     f.delete()
     assert(not f.exists())
@@ -192,10 +194,10 @@ def test_12_file_last_modified():
 def test_13_last_modified():
     sid = subj_1.id()
 
-    t1 = central.select('/project/nosetests5').last_modified()[sid]
+    t1 = central.select('/project/pyxnat_tests').last_modified()[sid]
     subj_1.attrs.set('age', '26')
     assert subj_1.attrs.get('age') == '26'
-    t2 = central.select('/project/nosetests5').last_modified()[sid]
+    t2 = central.select('/project/pyxnat_tests').last_modified()[sid]
 
     assert t1 != t2
 
@@ -222,18 +224,18 @@ def test_15_getitem_slice():
 
 
 def test_subject1_parent():
-    project = central.select.project('nosetests5')
+    project = central.select.project('pyxnat_tests')
     assert subj_1.parent()._uri == project._uri
 
 
 def test_project_parent():
-    project = central.select.project('nosetests5')
+    project = central.select.project('pyxnat_tests')
     assert not project.parent()
 
 
 @skip_if_no_network
 def test_16_project_configuration():
-    project = central.select('/project/nosetests5')
+    project = central.select('/project/pyxnat_tests')
     version = central.version()
     from pyxnat.core.errors import DatabaseError
 
@@ -244,7 +246,7 @@ def test_16_project_configuration():
         if version['version'] == '1.7.5.2-SNAPSHOT':
             msg = 'Version 1.7.5.2-SNAPSHOT gives trouble on some machines. \
                    Skipping it'
-            raise SkipTest(msg)
+            pytest.skip(msg)
 
     if version['version'] != '1.7.5.2-SNAPSHOT':
         try:
@@ -254,9 +256,9 @@ def test_16_project_configuration():
                   % version['version']
             print(msg)
 
-    assert 'nosetests' in project.users()
-    assert 'nosetests' in project.owners()
-    assert project.user_role('nosetests') == 'owner'
+    assert central._user in project.users()
+    assert central._user in project.owners()
+    assert project.user_role(central._user) == 'owner'
 
 
 @skip_if_no_network
@@ -300,13 +302,13 @@ def test_18_get_zip():
 
 @skip_if_no_network
 def test_19_project_aliases():
-    project = central.select('/project/nosetests5')
-    assert project.aliases() == ['nosetests52']
+    project = central.select('/project/pyxnat_tests')
+    assert project.aliases() == ['pyxnat']
 
 
 @skip_if_no_network
 def test_20_project():
-    project = central.select.project('nosetests5')
+    project = central.select.project('pyxnat_tests')
     project.datatype()
     project.experiments()
     project.experiment('nose')
@@ -314,77 +316,71 @@ def test_20_project():
 
 @skip_if_no_network
 def test_21_project_description():
-    project = central.select.project('nosetests5')
+    project = central.select.project('pyxnat_tests')
     desc = project.description()
-    assert(desc == 'nosetests')
+    assert desc == 'pyxnat CI tests'
 
 
 @skip_if_no_network
 def test_22_share_subject():
-    target_project = central.select.project('metabase_nosetests')
+    target_project = central.select.project('pyxnat_tests2')
 
     shared_subj_1 = target_project.subject(_id_set1['sid'])
-    assert(not shared_subj_1.exists())
-    assert(subj_1.shares().get() == ['nosetests5'])
+    assert (not shared_subj_1.exists())
+    assert (subj_1.shares().get() == ['pyxnat_tests'])
 
-    subj_1.share('metabase_nosetests')
+    subj_1.share('pyxnat_tests2')
     shared_subj_1 = target_project.subject(_id_set1['sid'])
-    assert(shared_subj_1.exists())
-    assert(subj_1.shares().get() == ['nosetests5', 'metabase_nosetests'])
+    assert (shared_subj_1.exists())
+    assert (subj_1.shares().get() == ['pyxnat_tests', 'pyxnat_tests2'])
 
 
 @skip_if_no_network
 def test_23_unshare_subject():
-    target_project = central.select.project('metabase_nosetests')
+    target_project = central.select.project('pyxnat_tests2')
 
     shared_subj_1 = target_project.subject(_id_set1['sid'])
-    assert(shared_subj_1.exists())
-    assert(subj_1.shares().get() == ['nosetests5', 'metabase_nosetests'])
+    assert (shared_subj_1.exists())
+    assert (subj_1.shares().get() == ['pyxnat_tests', 'pyxnat_tests2'])
 
-    subj_1.unshare('metabase_nosetests')
+    subj_1.unshare('pyxnat_tests2')
     shared_subj_1 = target_project.subject(_id_set1['sid'])
-    assert(not shared_subj_1.exists())
-    assert(subj_1.shares().get() == ['nosetests5'])
+    assert (not shared_subj_1.exists())
+    assert (subj_1.shares().get() == ['pyxnat_tests'])
 
 
 @skip_if_no_network
 def test_24_share_experiment():
-    target_project = central.select.project('metabase_nosetests')
+    target_project = central.select.project('pyxnat_tests2')
 
     shared_expe_1 = target_project.experiment(_id_set1['eid'])
-    assert(not shared_expe_1.exists())
-    assert(expe_1.shares().get() == ['nosetests5'])
+    assert (not shared_expe_1.exists())
+    assert (expe_1.shares().get() == ['pyxnat_tests'])
 
-    expe_1.share('metabase_nosetests')
+    expe_1.share('pyxnat_tests2')
     shared_expe_1 = target_project.experiment(_id_set1['eid'])
-    assert(shared_expe_1.exists())
-    assert(expe_1.shares().get() == ['nosetests5', 'metabase_nosetests'])
+    assert (shared_expe_1.exists())
+    assert (expe_1.shares().get() == ['pyxnat_tests', 'pyxnat_tests2'])
 
 
 @skip_if_no_network
 def test_25_unshare_experiment():
-    target_project = central.select.project('metabase_nosetests')
+    target_project = central.select.project('pyxnat_tests2')
 
     shared_expe_1 = target_project.experiment(_id_set1['eid'])
-    assert(shared_expe_1.exists())
-    assert(expe_1.shares().get() == ['nosetests5', 'metabase_nosetests'])
+    assert (shared_expe_1.exists())
+    assert (expe_1.shares().get() == ['pyxnat_tests', 'pyxnat_tests2'])
 
-    expe_1.unshare('metabase_nosetests')
+    expe_1.unshare('pyxnat_tests2')
     shared_expe_1 = target_project.experiment(_id_set1['eid'])
-    assert(not shared_expe_1.exists())
-    assert(expe_1.shares().get() == ['nosetests5'])
+    assert (not shared_expe_1.exists())
+    assert (expe_1.shares().get() == ['pyxnat_tests'])
 
 
 @skip_if_no_network
-def test_26_subject1_delete():
-    assert subj_1.exists()
-    subj_1.delete()
-    assert not subj_1.exists()
-
-
-@skip_if_no_network
-def test_27_subject2_delete():
-    subj_2 = central.select('/projects/nosetests5/subjects/%(sid)s' % _id_set2)
-    assert subj_2.exists()
-    subj_2.delete()
-    assert not subj_2.exists()
+def test_26_subjects_delete():
+    for sid in [_id_set1['sid'], _id_set2['sid']]:
+        subj = central.select.project('pyxnat_tests').subject(sid)
+        if subj.exists():
+            subj.delete(delete_files=True)
+        assert not subj.exists()
